==> rk.ClusterAnalysis_0.01-0.tar.gz: rk.ClusterAnalysis/inst/rkward/plugins/Determinenumberofclusters.js <==
// this code was generated using the rkwarddev package.
//perhaps don't make changes here, but in the rkwarddev script instead!

function preprocess(){
	// add requirements etc. here

}

function calculate(){
	// read in variables from dialog
	var vrslDtmtrxrd = getValue("vrsl_Dtmtrxrd");
	var chcRmvmssng = getValue("chc_Rmvmssng");
	var chcStdrdzvl = getValue("chc_Stdrdzvl");
	var radMethod = getValue("rad_Method");
	var spnMxmmnmbr = getValue("spn_Mxmmnmbr");
	var drpCmpttnmt = getValue("drp_Cmpttnmt");
	var spnPwrfMnkw = getValue("spn_PwrfMnkw");
	var drpAgglmrtn = getValue("drp_Agglmrtn");

	// the R code to be evaluated
	if(chcRmvmssng) {
		echo("\t# Listwise removal of missings\n\t" + vrslDtmtrxrd + " <- na.omit(" + vrslDtmtrxrd + ")\n");
	} else {}
	if(chcStdrdzvl) {
		echo("\t# Standardizing values\n\t" + vrslDtmtrxrd + " <- scale(" + vrslDtmtrxrd + ")\n");
	} else {}
	if(radMethod == "kmeans" && vrslDtmtrxrd) {
		echo("\t# Calculate within groups sum of squares" + "\n\tclust.wss <- (nrow(" + vrslDtmtrxrd + ")-1) * sum(apply(" + vrslDtmtrxrd + ", 2, var))\n" + "\tfor (i in 2:" + spnMxmmnmbr + "){\n\t\tclust.wss[i] <- kmeans(" + vrslDtmtrxrd + ", centers=i)$tot.withinss\n\t}\n\n");
	} else {}
	if(radMethod == "hclust" && vrslDtmtrxrd) {
		echo("\t# Get clustering criterion" + "\n\tclust.from <- nrow(" + vrslDtmtrxrd + ")-" + spnMxmmnmbr + "\n\tclust.to <- nrow(" + vrslDtmtrxrd + ")-1" + "\n\tclust.wss <- hclust(dist(" + vrslDtmtrxrd + ", method=\"" + drpCmpttnmt + "\"), method=\"" + drpAgglmrtn + "\")$height[clust.from:clust.to]\n\n");
	} else {}
}

function printout(){
	// all the real work is moved to a custom defined function doPrintout() below
	// true in this case means: We want all the headers that should be printed in the output:
	doPrintout(true);
}

function preview(){
	preprocess();
	calculate();
	doPrintout(false);
}

function doPrintout(full){
	// read in variables from dialog
	var vrslDtmtrxrd = getValue("vrsl_Dtmtrxrd");
	var chcRmvmssng = getValue("chc_Rmvmssng");
	var chcStdrdzvl = getValue("chc_Stdrdzvl");
	var radMethod = getValue("rad_Method");
	var spnMxmmnmbr = getValue("spn_Mxmmnmbr");
	var drpCmpttnmt = getValue("drp_Cmpttnmt");
	var spnPwrfMnkw = getValue("spn_PwrfMnkw");
	var drpAgglmrtn = getValue("drp_Agglmrtn");

	// create the plot
	if(full) {
		echo("rk.header(\"Determine number of clusters results\", level=1)\n");
	} else {}

	if(full) {
		echo("rk.graph.on()\n");
	} else {}
	echo("\ttry({\n\t\tplot(\n\t\t\t");
	if(radMethod == "kmeans") {
		echo("1:" + spnMxmmnmbr + ",\n\t\t\tclust.wss,\n\t\t\ttype=\"b\",\n\t\t\txlab=\"Number of Clusters\",\n\t\t\tylab=\"Within groups sum of squares\"," + "\n\t\t\tmain=\"Within sum of squares by clusters\",\n\t\t\tsub=\"Examined " + spnMxmmnmbr + " clusters using k-means partitioning\")");
	} else {}
	if(radMethod == "hclust") {
		echo("clust.wss,\n\t\t\ttype=\"b\",\n\t\t\txlab=\"Number of Clusters\",\n\t\t\tylab=\"Agglomeration criterion\",\n\t\t\txaxt=\"n\"," + "\n\t\t\tmain=\"Inverse Scree plot\",\n\t\t\tsub=\"Examined " + spnMxmmnmbr + " clusters (dist: " + drpCmpttnmt + ", hclust: " + drpAgglmrtn + ")\")" + "\n\t\taxis(1, at=1:" + spnMxmmnmbr + ", labels=" + spnMxmmnmbr + ":1)");
	} else {}
	echo("\n\t})\n");
	if(full) {
		echo("rk.graph.off()\n");
	} else {}
}

==> rk.ClusterAnalysis_0.01-1.tar.gz: rk.ClusterAnalysis/inst/rkward/plugins/Determinenumberofclusters.js <==
// this code was generated using the rkwarddev package.
//perhaps don't make changes here, but in the rkwarddev script instead!

function preprocess(){
	// add requirements etc. here

}

function calculate(){
	// read in variables from dialog
	var vrslDtmtrxrd = getValue("vrsl_Dtmtrxrd");
	var chcRmvmssng = getValue("chc_Rmvmssng");
	var chcStdrdzvl = getValue("chc_Stdrdzvl");
	var radMethod = getValue("rad_Method");
	var spnMxmmnmbr = getValue("spn_Mxmmnmbr");
	var drpCmpttnmt = getValue("drp_Cmpttnmt");
	var spnPwrfMnkw = getValue("spn_PwrfMnkw");
	var drpAgglmrtn = getValue("drp_Agglmrtn");

	// the R code to be evaluated
	if(chcRmvmssng) {
		echo("\t# Listwise removal of missings\n\t" + vrslDtmtrxrd + " <- na.omit(" + vrslDtmtrxrd + ")\n");
	} else {}
	if(chcStdrdzvl) {
		echo("\t# Standardizing values\n\t" + vrslDtmtrxrd + " <- scale(" + vrslDtmtrxrd + ")\n");
	} else {}
	if(radMethod == "kmeans" && vrslDtmtrxrd) {
		echo("\t# Calculate within groups sum of squares" + "\n\tclust.wss <- (nrow(" + vrslDtmtrxrd + ")-1) * sum(apply(" + vrslDtmtrxrd + ", 2, var))\n" + "\tfor (i in 2:" + spnMxmmnmbr + "){\n\t\tclust.wss[i] <- kmeans(" + vrslDtmtrxrd + ", centers=i)$tot.withinss\n\t}\n\n");
	} else {}
	if(radMethod == "hclust" && vrslDtmtrxrd) {
		echo("\t# Get clustering criterion" + "\n\tclust.from <- nrow(" + vrslDtmtrxrd + ")-" + spnMxmmnmbr + "\n\tclust.to <- nrow(" + vrslDtmtrxrd + ")-1" + "\n\tclust.wss <- hclust(dist(" + vrslDtmtrxrd + ", method=\"" + drpCmpttnmt + "\"), method=\"" + drpAgglmrtn + "\")$height[clust.from:clust.to]\n\n");
	} else {}
}

function printout(){
	// all the real work is moved to a custom defined function doPrintout() below
	// true in this case means: We want all the headers that should be printed in the output:
	doPrintout(true);
}

function preview(){
	preprocess();
	calculate();
	doPrintout(false);
}

function doPrintout(full){
	// read in variables from dialog
	var vrslDtmtrxrd = getValue("vrsl_Dtmtrxrd");
	var chcRmvmssng = getValue("chc_Rmvmssng");
	var chcStdrdzvl = getValue("chc_Stdrdzvl");
	var radMethod = getValue("rad_Method");
	var spnMxmmnmbr = getValue("spn_Mxmmnmbr");
	var drpCmpttnmt = getValue("drp_Cmpttnmt");
	var spnPwrfMnkw = getValue("spn_PwrfMnkw");
	var drpAgglmrtn = getValue("drp_Agglmrtn");

	// create the plot
	if(full) {
		echo("rk.header(\"Determine number of clusters results\", level=1)\n");
	} else {}

	// in case there are generic plot options defined:

	var embGnrcpltpCodePrintout = getValue("emb_Gnrcpltp.code.printout");
	if(full) {
		echo("rk.graph.on()\n");
	} else {}
	echo("\ttry({\n\t\tplot(\n\t\t\t");
	if(radMethod == "kmeans") {
				echo("1:" + spnMxmmnmbr + ",\n\t\t\tclust.wss");
		if(!embGnrcpltpCodePrintout.match(/type\s*=/)) {
			echo(",\n\t\t\ttype=\"b\"");
		} else {}
		if(!embGnrcpltpCodePrintout.match(/xlab\s*=/)) {
			echo(",\n\t\t\txlab=\"Number of Clusters\"");
		} else {}
		if(!embGnrcpltpCodePrintout.match(/ylab\s*=/)) {
			echo(",\n\t\t\tylab=\"Within groups sum of squares\"");
		} else {}
		if(!embGnrcpltpCodePrintout.match(/main\s*=/)) {
			echo(",\n\t\t\tmain=\"Within sum of squares by clusters\"");
		} else {}
		if(!embGnrcpltpCodePrintout.match(/sub\s*=/)) {
			echo(",\n\t\t\tsub=\"Examined " + spnMxmmnmbr + " clusters using k-means partitioning\"");
		} else {}
		echo(embGnrcpltpCodePrintout + ")");
	} else {}
	if(radMethod == "hclust") {
				echo("clust.wss");
		if(!embGnrcpltpCodePrintout.match(/type\s*=/)) {
			echo(",\n\t\t\ttype=\"b\"");
		} else {}
		if(!embGnrcpltpCodePrintout.match(/xlab\s*=/)) {
			echo(",\n\t\t\txlab=\"Number of Clusters\"");
		} else {}
		if(!embGnrcpltpCodePrintout.match(/ylab\s*=/)) {
			echo(",\n\t\t\tylab=\"Agglomeration criterion\"");
		} else {}
		if(!embGnrcpltpCodePrintout.match(/main\s*=/)) {
			echo(",\n\t\t\tmain=\"Inverse Scree plot\"");
		} else {}
		if(!embGnrcpltpCodePrintout.match(/sub\s*=/)) {
			echo(",\n\t\t\tsub=\"Examined " + spnMxmmnmbr + " clusters (dist: " + drpCmpttnmt + ", hclust: " + drpAgglmrtn + ")\"");
		} else {}
		echo(",\n\t\t\txaxt=\"n\"" + embGnrcpltpCodePrintout + ")\n\t\t" + "axis(1, at=1:" + spnMxmmnmbr + ", labels=" + spnMxmmnmbr + ":1)");
	} else {}
	echo("\n\t})\n");
	if(full) {
		echo("rk.graph.off()\n");
	} else {}
}
